@@ -1,3 +1,7 @@
+"""
+models for hosts, domains, service updaters, ...
+"""
+
 import re
 import base64
 
@@ -160,8 +164,8 @@ class Host(models.Model):
     last_update_ipv4 = models.DateTimeField(blank=True, null=True)
     last_update_ipv6 = models.DateTimeField(blank=True, null=True)
     # how we received the last update for v4/v6 addr
-    ssl_update_ipv4 = models.BooleanField()
-    ssl_update_ipv6 = models.BooleanField()
+    ssl_update_ipv4 = models.BooleanField(default=False)
+    ssl_update_ipv6 = models.BooleanField(default=False)
 
     last_update = models.DateTimeField(auto_now=True)
     created = models.DateTimeField(auto_now_add=True)
