@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+"""
+views for the interactive web user interface
+"""
 
 from datetime import timedelta
 
@@ -139,6 +142,28 @@ class StatusView(TemplateView):
         return context
 
 
+from nsupdate.api.views import basic_challenge, basic_authenticate
+
+
+class JsUpdateView(TemplateView):
+    template_name = "main/update.html"
+
+    def get(self, request, *args, **kwargs):
+        auth = request.META.get('HTTP_AUTHORIZATION')
+        if auth is None:
+            return basic_challenge("authenticate to update DNS", 'badauth')
+        username, password = basic_authenticate(auth)
+        self.hostname = username
+        self.secret = password
+        return super(JsUpdateView, self).get(request, *args, **kwargs)
+
+    def get_context_data(self, *args, **kwargs):
+        context = super(JsUpdateView, self).get_context_data(*args, **kwargs)
+        context['hostname'] = self.hostname
+        context['secret'] = self.secret
+        return context
+
+
 class OverviewView(CreateView):
     model = Host
     template_name = "main/overview.html"
@@ -416,23 +441,29 @@ Disallow: /account/
 Disallow: /accounts/
 Disallow: /login/
 Disallow: /admin/
-Disallow: /myip/
-Disallow: /nic/update/
-Disallow: /overview/
-Disallow: /domain_overview/
-Disallow: /host/
-Disallow: /domain/
 Disallow: /status/
+Disallow: /myip/
+Disallow: /detect_ip/
 Disallow: /ajax_get_ips/
+Disallow: /nic/update/
+Disallow: /nic/update_authorized/
+Disallow: /update/
+Disallow: /host/
+Disallow: /overview/
+Disallow: /domain/
+Disallow: /domain_overview/
+Disallow: /updater_hostconfig/
+Disallow: /updater_hostconfig_overview/
 """
         return HttpResponse(content, content_type="text/plain")
 
 
-def csrf_failure_view(request, reason):
+def csrf_failure_view(request, reason):  # pragma: no cover (hard to test)
     """
     Django's CSRF middleware's builtin view doesn't tell the user that he needs to have cookies enabled.
 
     :param request: django request object
+    :param reason: why the csrf check failed
     :return: HttpResponse object
     """
     if reason == "CSRF cookie not set.":
